@@ -11,10 +11,13 @@ from beneath.checkpointer import Checkpointer
 from beneath.consumer import Consumer
 from beneath.cursor import Cursor
 from beneath.easy import (
-    easy_consume_stream,
-    easy_derive_stream,
-    easy_generate_stream,
-    easy_read,
+    consume,
+    load_full,
+    query_warehouse,
+    write_full,
+    generate_stream_pipeline,
+    derive_stream_pipeline,
+    consume_stream_pipeline,
 )
 from beneath.instance import StreamInstance
 from beneath.job import Job, JobStatus
@@ -30,10 +33,6 @@ __all__ = [
     "Client",
     "Consumer",
     "Cursor",
-    "easy_consume_stream",
-    "easy_derive_stream",
-    "easy_generate_stream",
-    "easy_read",
     "Job",
     "JobStatus",
     "Pipeline",
@@ -43,4 +42,11 @@ __all__ = [
     "Strategy",
     "Stream",
     "StreamInstance",
+    "consume",
+    "load_full",
+    "query_warehouse",
+    "write_full",
+    "generate_stream_pipeline",
+    "derive_stream_pipeline",
+    "consume_stream_pipeline",
 ]
